import os
from django.contrib import admin
from django.utils.html import format_html
from django.utils.translation import ugettext_lazy as _

from ..db_router import TestRouter
from ..models.notification import Notification

class NotificationAdmin(admin.ModelAdmin):
    list_display = ('notification_id', 'internal_name', 'message_title', 'active' )
    fields = ('internal_name', 'internal_description', 'message_title', 'message_body', 'image_url', 'get_image_preview', 'schedule_date', 'schedule_hook', 'schedule_sql', 'active' )
    list_editable = ('internal_name', 'active')
    readonly_fields = ("get_image_preview",)

    def get_image_preview(self, obj):
        image_url = '/media/' + str(obj.image_url)
        if obj.pk:
            return format_html('<img src="{url}" title="{url}" width="30%" height="30%"/> ' \
                               .format(url=image_url))

    get_image_preview.short_description = _("Image Preview")

    def clone_notification(self, request, queryset):
        for notif in queryset:
            notif.pk = None
            notif.internal_name = notif.internal_name + "_copy"
            notif.save()

    clone_notification.short_description = "Clone the selected notification"

    def sync_notification(self, request, queryset):
        TestRouter.cloning = True
        for notif in queryset:
            live_qs = Notification.objects.using('live').raw(f'SELECT * from notification WHERE notification_id = {notif.pk}')
            if len(list(live_qs)) == 0:
                print("New notification to sync")
                live_notif = Notification()
                live_notif.pk = None
                live_notif.internal_name = notif.internal_name
                live_notif.internal_description = notif.internal_description
                live_notif.message_title = notif.message_title
                live_notif.message_body = notif.message_body
                live_notif.image_url = notif.image_url
                live_notif.schedule_date = notif.schedule_date
                live_notif.schedule_hook = notif.schedule_hook
                live_notif.schedule_sql = notif.schedule_sql
                live_notif.active = notif.active
                live_notif.save()
            else:
                for live_notif in live_qs:
                    print(f'Update notification to sync {notif.internal_name} - Live: {live_notif.internal_name}')
                    live_notif.internal_name = notif.internal_name
                    live_notif.internal_description = notif.internal_description
                    live_notif.message_title = notif.message_title
                    live_notif.message_body = notif.message_body
                    live_notif.image_url = notif.image_url
                    live_notif.schedule_date = notif.schedule_date
                    live_notif.schedule_hook = notif.schedule_hook
                    live_notif.schedule_sql = notif.schedule_sql
                    live_notif.active = notif.active
                    live_notif.save()
        TestRouter.cloning = False

    sync_notification.short_description = "Syncrchnonize with the live database"

    actions = [clone_notification, sync_notification]




admin.site.register(Notification, NotificationAdmin)
admin.autodiscover()